==========
User Guide
==========

Verwende stanpy in einem Projekt mit::

    import stanpy as stp

Was ist stanpy?
---------------
Stanpy ist (in einem ersten Schritt) ein kleines Package zur Lösung gerader Stabzüge mit konstanter oder linear veränderlichen Querschnittsabmessungen nach Theorie I. oder II. Ordnung.
Gelöst werden die Problemstellung mithilfe des Reduktionsverfahrens der Baustatik.

Inhaltsverzeichnis
------------------

.. toctree::
    :maxdepth: 2
    :caption: User Guide

    cross_section
    cross_section_height
    straight_beam_constant_cs
    straight_beam_non_constant_cs
    reduction_method
    .. transfer_relation


.. meta::
    :description lang=en:
        A collection of examples for demonstrating the features of the stanpy.